import Feature from "./Feature";
import Permission from "./Permission";
import PricingTier from "./PricingTier";
import Role from "./Role";
import Tenant from "./Tenant";
import Warrant from "./WarrantModule";
import { ListFeatureOptions } from "../types/Feature";
import { ListPermissionOptions } from "../types/Permission";
import { ListPricingTierOptions } from "../types/PricingTier";
import { ListRoleOptions } from "../types/Role";
import { CreateUserParams, ListUserOptions, UpdateUserParams } from "../types/User";
import { ListTenantOptions } from "../types/Tenant";
import { Context, WarrantObject } from "../types/Warrant";
export default class User implements WarrantObject {
    userId: string;
    email?: string;
    constructor(userId: string, email?: string);
    static create(user?: CreateUserParams): Promise<User>;
    static batchCreate(users: CreateUserParams[]): Promise<User[]>;
    static get(userId: string): Promise<User>;
    static update(userId: string, user: UpdateUserParams): Promise<User>;
    static delete(userId: string): Promise<void>;
    static listUsers(listOptions?: ListUserOptions): Promise<User[]>;
    static listUsersForTenant(tenantId: string, listOptions?: ListUserOptions): Promise<User[]>;
    static assignUserToTenant(tenantId: string, userId: string): Promise<Warrant>;
    static removeUserFromTenant(tenantId: string, userId: string): Promise<void>;
    listTenants(listOptions?: ListTenantOptions): Promise<Tenant[]>;
    listRoles(listOptions?: ListRoleOptions): Promise<Role[]>;
    assignRole(roleId: string): Promise<Role>;
    removeRole(roleId: string): Promise<void>;
    listPermissions(listOptions?: ListPermissionOptions): Promise<Permission[]>;
    assignPermission(permissionId: string): Promise<Permission>;
    removePermission(permissionId: string): Promise<void>;
    hasPermission(permissionId: string, context?: Context): Promise<boolean>;
    listPricingTiers(listOptions?: ListPricingTierOptions): Promise<PricingTier[]>;
    assignPricingTier(pricingTierId: string): Promise<PricingTier>;
    removePricingTier(pricingTierId: string): Promise<void>;
    listFeatures(listOptions?: ListFeatureOptions): Promise<Feature[]>;
    assignFeature(featureId: string): Promise<Feature>;
    removeFeature(featureId: string): Promise<void>;
    hasFeature(featureId: string, context?: Context): Promise<boolean>;
    getObjectType(): string;
    getObjectId(): string;
}
