"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ErrorCode = void 0;
var ErrorCode;
(function (ErrorCode) {
    ErrorCode["GenericError"] = "generic_error";
    ErrorCode["InternalError"] = "internal_error";
    ErrorCode["InvalidArgument"] = "invalid_argument";
    ErrorCode["InvalidParameter"] = "invalid_parameter";
    ErrorCode["InvalidRequest"] = "invalid_request";
    ErrorCode["MissingParameter"] = "missing_parameter";
    ErrorCode["NotFound"] = "not_found";
    ErrorCode["DuplicateRecord"] = "duplicate_record";
    ErrorCode["Unauthorized"] = "unauthorized";
})(ErrorCode = exports.ErrorCode || (exports.ErrorCode = {}));
class ApiError extends Error {
    constructor(code, message) {
        super(message);
        this.code = code;
        this.message = message;
        this.name = ApiError.codeToName(code);
    }
    toString() {
        return `${this.name} [${this.code}]: ${this.message}`;
    }
    static codeToName(code) {
        switch (code) {
            case ErrorCode.DuplicateRecord:
                return "DuplicateRecordError";
            case ErrorCode.InternalError:
                return "InternalError";
            case ErrorCode.InvalidRequest:
                return "InvalidRequestError";
            case ErrorCode.InvalidParameter:
                return "InvalidParameterError";
            case ErrorCode.MissingParameter:
                return "MissingRequiredParameterError";
            case ErrorCode.NotFound:
                return "NotFoundError";
            case ErrorCode.Unauthorized:
                return "UnauthorizedError";
            default:
                return "ApiError";
        }
    }
}
exports.default = ApiError;
